
/**
 * @vue-cdk/tooltip
 * Version: 0.5.0,
 * (c) Christian Kienle, 2020
 * LICENCE: MIT
 * https://github.com/ChristianKienle/cdk
*/
import pluginify from '@vue-cdk/pluginify';
import Popover from '@vue-cdk/popover/src/popover';
import Vue from 'vue';

var script = {
  name: 'Tooltip',
  components: {
    Popover: Popover
  },
  props: {
    noArrow: {
      type: Boolean,
      default: false
    },
    visible: {
      type: Boolean,
      default: false
    },
    theme: {
      type: String,
      default: null
    },
    text: {
      type: String,
      default: null
    },
    placement: {
      type: String,
      default: 'top'
    }
  },
  computed: {
    popoverTheme: function popoverTheme() {
      var theme = this.theme;

      if (theme == null) {
        return null;
      }

      return "tooltip-".concat(this.theme);
    }
  },
  watch: {
    visible: function visible(_visible) {
      var $_popover = this.$_popover;

      if ($_popover == null) {
        return;
      }

      $_popover.visible = _visible;
    },
    popoverTheme: function popoverTheme(_popoverTheme) {
      var $_popover = this.$_popover;

      if ($_popover == null) {
        return;
      }

      $_popover.theme = _popoverTheme;
    }
  },
  beforeUpdate: function beforeUpdate() {
    if (this.$el == null) {
      return;
    }

    if (this.$_showHandler != null) {
      this.$el.removeEventListener('mouseenter', this.$_showHandler);
      this.$_showHandler = null;
    }

    if (this.$_hideHandler != null) {
      this.$el.removeEventListener('mouseleave', this.$_hideHandler);
      this.$_hideHandler = null;
    }
  },
  updated: function updated() {
    var _this = this;

    var $el = this.$el;

    if ($el == null) {
      return;
    }

    this.$_showHandler = function () {
      _this.$_popover.show();
    };

    this.$el.addEventListener('mouseenter', this.$_showHandler);

    this.$_hideHandler = function () {
      _this.$_popover.hide();
    };

    this.$el.addEventListener('mouseleave', this.$_hideHandler);
  },
  created: function created() {
    this.$_showHandler = null;
    this.$_hideHandler = null;
  },
  destroy: function destroy() {
    this.$_popover.$destory();
  },
  mounted: function mounted() {
    var _this2 = this;

    var target = function target() {
      return _this2.$el;
    };

    var parent = this;
    var theme = this.popoverTheme;

    var renderContent = function renderContent(h, props) {
      var text = _this2.text,
          $scopedSlots = _this2.$scopedSlots;

      if (text != null) {
        return h('div', [text]);
      }

      return $scopedSlots.content(props);
    };

    this.$_popover = new Vue({
      components: {
        Popover: Popover
      },
      data: function data() {
        return {
          theme: theme,
          noArrow: parent.noArrow,
          visible: parent.visible,
          placement: parent.placement
        };
      },
      methods: {
        show: function show() {
          this.visible = true;
        },
        hide: function hide() {
          this.visible = false;
        }
      },
      render: function render(h) {
        var props = {
          target: target,
          withArrow: !this.noArrow,
          visible: this.visible,
          theme: this.theme,
          placement: this.placement
        };
        var scopedSlots = {
          default: function _default(popoverProps) {
            return renderContent(h, popoverProps);
          }
        };
        return h(Popover, {
          parent: parent,
          props: props,
          scopedSlots: scopedSlots
        });
      }
    }).$mount();
    this.$forceUpdate();
  },
  render: function render(h) {
    return this.$slots.default;
  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
/* server only */
, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
  if (typeof shadowMode !== 'boolean') {
    createInjectorSSR = createInjector;
    createInjector = shadowMode;
    shadowMode = false;
  } // Vue.extend constructor export interop.


  var options = typeof script === 'function' ? script.options : script; // render functions

  if (template && template.render) {
    options.render = template.render;
    options.staticRenderFns = template.staticRenderFns;
    options._compiled = true; // functional template

    if (isFunctionalTemplate) {
      options.functional = true;
    }
  } // scopedId


  if (scopeId) {
    options._scopeId = scopeId;
  }

  var hook;

  if (moduleIdentifier) {
    // server build
    hook = function hook(context) {
      // 2.3 injection
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
      // 2.2 with runInNewContext: true

      if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
        context = __VUE_SSR_CONTEXT__;
      } // inject component styles


      if (style) {
        style.call(this, createInjectorSSR(context));
      } // register component module identifier for async chunk inference


      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    }; // used by ssr in case component is cached and beforeCreate
    // never gets called


    options._ssrRegister = hook;
  } else if (style) {
    hook = shadowMode ? function (context) {
      style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
    } : function (context) {
      style.call(this, createInjector(context));
    };
  }

  if (hook) {
    if (options.functional) {
      // register for functional component in vue file
      var originalRender = options.render;

      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      // inject component registration as beforeCreate hook
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }

  return script;
}

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = normalizeComponent({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

var index = pluginify(__vue_component__);

export default index;
